Optimization
============

.. automodule:: mumott.optimization

.. index::
   single: Class reference; OptimizationParameters

OptimizationParameters
----------------------

.. autoclass:: mumott.optimization.OptimizationParameters
   :members:
   :undoc-members:


.. index::
   single: Class reference; OptimizationTimer

OptimizationTimer
-----------------

.. autoclass:: mumott.optimization.OptimizationTimer
   :members:
   :undoc-members:


.. index::
   single: Class reference; Optimizer

Optimizer
---------

.. autoclass:: mumott.optimization.Optimizer
   :members:
   :undoc-members:

.. index::
   single: Class reference; RegularizationCurveFinder

RegularizationCurveFinder
-------------------------

.. autoclass:: mumott.optimization.RegularizationCurveFinder
   :members:
   :undoc-members:

.. index::
   single: Class reference; Regularizer

Regularizer
-----------

.. autoclass:: mumott.optimization.Regularizer
   :members:
   :undoc-members:

.. index::
   single: Class reference; RegularizationParameters

RegularizationParameters
------------------------

.. autoclass:: mumott.optimization.RegularizationParameters
    :members:
    :undoc-members:

.. index::
   single: Class reference; VarianceEstimator

VarianceEstimator
-----------------

.. autoclass:: mumott.optimization.VarianceEstimator
    :members:
    :undoc-members: